%IMGCROP  Mark a sub-image in an image interactively.
%   b = imgcrop  Lets you mark a rectangular region in the active image
%   with mouse. Returns b such that the cropped sub-image is I(b(1):b(2),b(3):b(4)).
%
%   Example: I=64*rand(10); figure(1); image(I); b=imgcrop; figure(2); image(I(b(1):b(2),b(3):b(4)));

function b = imgcrop

b = dragbox;
b = [ceil(b(3)) floor(b(3)+b(4)) ceil(b(1)) floor(b(1)+b(2))];

x = [b(3) b(4)]; y = [b(1) b(2)];
h = ishold;
hold on
plot([x(1) x(1) x(2) x(2) x(1)],[y(1) y(2) y(2) y(1) y(1)],'r');
if ~h
  hold off
end

disp 'Press ENTER to continue'
pause

return


%DRAGBOX  Lets user enter a box region interactively.
%   b = dragbox  lets user drag a rubber box interactively
%   in the current axes and returns box b=[x xwid y ywid].

function b = dragbox

waitforbuttonpress;
point1 = get(gca,'CurrentPoint');    % button down detected
finalRect = rbbox;                   % return figure units
point2 = get(gca,'CurrentPoint');    % button up detected
point1 = point1(1,1:2);              % extract x and y
point2 = point2(1,1:2);
p = min(point1,point2);              % calculate locations
d = abs(point1-point2);              % and dimensions
b = [p(1) d(1) p(2) d(2)];

return