function [U,V] = rc2uv(r,c)
% RC2UV create matrices of u- and -v coordinates
%       useful for creating frequency filters
%
% [U,V] = rc2uv(r,c)
% r ... number of rows (image height)
% c ... number of columns (image width)
%
% U ... [r x c] matrix of u coordinates (x-direction)
% V ... [r x c] matrix of v coordinates (y-direction)
% 
% for better understanding, try the following
% [U,V] = rc2uv(5,6)
% matrix of Euclidean distances is then D=sqrt(U.^2+V.^2)
%
% Example: 100x100 image of a circle with radius=20 in the center
% 
% [u,v]=rc2uv(100,100);
% a=zeros(100,100);
% d=sqrt(u.^2+v.^2);
% b=a; 
% b(d<20)=1;
% imshow(b)
% axis on
% 
% See also: MESHGRID, FFTSHIFT
%
% Tomas Svoboda, 08/2005

u = [0:c-1];
v = [0:r-1];

idx = find(u>=c/2);
u(idx) = u(idx)-c;

idx = find(v>=r/2);
v(idx) = v(idx)-r;

U = fftshift(repmat(u,r,1));
V = fftshift(repmat(v',1,c));

return;
